@@ -1,5 +1,5 @@
 ## ionize.aa(): Contour plots of net charge and ionization properties of LYSC_CHICK
-aa <- ip2aa("LYSC_CHICK")
+aa <- pinfo(pinfo("LYSC_CHICK"))
 pH <- seq(0, 14, 0.2)
 T <- seq(0, 200, 2)
 val <- expand.grid(pH=pH, T=T)
